#
# spec file for package almanah
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           almanah
Version:        0.12.4
Release:        1.3
Summary:        GTK+ application to allow you to keep a diary of your life
License:        GPL-3.0+
Group:          Productivity/Office/Other
URL:            https://gitlab.gnome.org/GNOME/almanah
Source:         https://download.gnome.org/sources/almanah/0.12/%{name}-%{version}.tar.xz

BuildRequires:  desktop-file-utils
BuildRequires:  gpgme-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  intltool
BuildRequires:  meson >= 0.51
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(atk)
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(cryptui-0.0)
BuildRequires:  pkgconfig(gcr-4)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gmodule-2.0)
BuildRequires:  pkgconfig(gthread-2.0)
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.5.6
BuildRequires:  pkgconfig(gtksourceview-4)
BuildRequires:  pkgconfig(gtkspell3-3.0)
BuildRequires:  pkgconfig(libecal-2.0)
BuildRequires:  pkgconfig(libedataserver-1.2)
BuildRequires:  pkgconfig(sqlite3)
Requires:       evolution-data-server

%description
Almanah Diary is a small application to ease the management of an encrypted
personal diary. It's got good editing abilities, including text formatting
and printing. Evolution tasks and appointments will be listed to ease the
creation of diary entries related to them. At the same time, you can create
diary entries using multiple events.

%lang_package

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install

%find_lang %{name} %{?no_lang_C}

%check
%meson_test

%files
%license COPYING
%doc AUTHORS NEWS.md README.md
%{_bindir}/%{name}
%{_datadir}/glib-2.0/schemas/org.gnome.%{name}.gschema.xml
%{_datadir}/applications/org.gnome.Almanah.desktop
%{_datadir}/icons/hicolor/*/apps/org.gnome.Almanah.png
%{_datadir}/icons/hicolor/scalable/a*/org.gnome.Almanah-*.svg
%{_datadir}/metainfo/org.gnome.Almanah.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Sat Jan 11 2025 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.12.4:
  + Added:
  - Search (Ctrl-F) and Quit (Ctrl-Q) keyboard shortcuts
  - Nix-based development environment and CI
  + Fixed:
  - Various deprecations
  - Localization of aplication name
  + Changed: Application ID and icon name is now rDNS
    (org.gnome.Almanah) instead of just almanah
  + Changed dependencies:
  - GTKSourceView 3 → GTKSourceView 4
  - Gcr 3 → Gcr 4
  - appstream-util → appstreamcli
  + Updated translations.
- Drop Fix-build-meson-060.patch: Fixed upstream.
- Changes in BuildRequires following upstream changes:
  + Drop: update-desktop-files, pkgconfig(gcr-base-3) and
    pkgconfig(gtksourceview-3.0)
  + Add: desktop-file-utils, pkgconfig(gtksourceview-4) and
    pkgconfig(gcr-4)
- Add check section and run meson_test macro during build.
* Mon Nov  6 2023 Dominique Leuenberger <dimstar@opensuse.org>
-  Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Tue Feb 22 2022 Bjørn Lie <bjorn.lie@gmail.com>
- Add Fix-build-meson-060.patch: Fix build with meson 0.60.x and
  newer.
* Mon Apr 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 0.12.3
  * Fixed: Font size is too small in text view
  * Updated Catalan translation
* Fri Sep  4 2020 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.12.2:
  + Fix version number (no other changes).
- Changes from version 0.12.1:
  + Bump Meson dependency to 0.51 to simplify build system.
  + Bugs fixed: typo in src/vfs.c errors.
  + Updated translations.
* Mon Oct  7 2019 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 0.12.0:
  + Move encryption support to SQLiteVFS to improve performance and
    reduce the chance of data loss from use of temporary files.
  + Various GTK version and API updates.
  + Migrated from GtkToolbar to GtkHeaderBar.
  + Various AppData file updates.
  + Support undo and redo.
  + Port to Meson.
  + Port to libecal-2.0.
  + Bugs fixed:
  - Meson build claims implicit function declaration warnings.
  - build: Port to meson.
  - docs: Port README to Markdown and update it.
  - event-factories: Fix an incorrect string comparison.
  + Updated translations.
- Add meson BuildRequires and macros following upstreams port.
- Replace pkgconfig(libecal-1.2) with pkgconfig(libecal-2.0)
  BuildRequires.
- Add pkgconfig(gtksourceview-3.0) and pkgconfig(gcr-base-3)
  BuildRequires: New dependencies.
- Add explicit pkgconfig(glib-2.0), pkgconfig(gmodule-2.0),
  pkgconfig(gthread-2.0), pkgconfig(gio-2.0) and pkgconfig(sqlite3)
  BuildRequires and drop sqlite3-devel BuildRequires: Align with
  what meson checks for.
- Drop almanah-lang Recommends: No longer needed.
- Drop glib2_gsettings_schema_post(un), icon_theme_cache_post(un)
  desktop_database_post(un) and glib2_gsettings_schema_requires
  macros, no longer needed by any supported versions of openSUSE.
* Thu Sep 25 2014 dimstar@opensuse.org
- Update to version 0.11.1:
  + Improved AppData support for Software App.
  + Updated translations.
* Sat Nov 30 2013 dimstar@opensuse.org
- Update to version 0.11.0:
  + Improved the tagging accesibility.
  + Enhanced the diary security.
  + Changed the tagging look (new button with a symbolic link in
    the toolbar and the tag bar shown integrated in the main
    toolbar).
  + Added a new 256x256 icon, that looks better in GNOME Shell.
  + Added an AppData file to show a completed information in
    Software App.
  + Updated translations.
- Drop almanah-includes.patch: fixed upstream.
- Pass install_sh=$(pwd)/install-sh to make_install: for some weird
  reason, the tarball fails to find it.
* Thu Apr 18 2013 dimstar@opensuse.org
- Update to version 0.10.8:
  + Main window redesign.
  + Tagging support.
  + Port to GMenu.
  + Dropped the libedataserverui dependency and embed the
    ECellRendererColor and ESourceSelector widgets.
  + Hide the title bar in maximized windows.
  + Updated GtkSpell 3 support.
  + Updated EDS dependency to 3.5.91.
  + Bugs fixed: bgo#677209, bgo#680845.
  + Updated translations.
- Replace pkgconfig(gtkspell-3.0) BuildRequires with
  pkgconfig(gtkspell3-3.0), following upstream.
- Drop pkgconfig(libedataserverui-3.0) BuildRequires: no longer
  needed.
- Add -UE_CAL_DISABLE_DEPRECATED to CFLAGS, in order to allow
  deprecated E_CAL functions.
- Add almanah-includes.patch: include interface.h to fix build.
* Sun Mar 17 2013 zaitor@opensuse.org
- Update to version 0.10.1:
  + Almanah doesn't encrypt the database when the application close
    (bgo#695117, bnc#809140, CVE-2013-1853).
* Sat Sep 22 2012 dimstar@opensuse.org
- Update to version 0.10.0:
  + Major changes:
  - Updated EDS events integration to the new 3.5.91 API
  - Second phase of the new UI
  - Now is set the default file name when the user doing "Print
    to File"
  - Updated HACKING doc with general principles and a security
    policy
  + Bugs fixed: bgo#683570, bgo#680845, bgo#676765, bgo#676931,
    bgo#676766
  + Updated translations.
- Drop pkgconfig(gconf-2.0) BuildRequires: no longer needed.
* Thu Mar 29 2012 dimstar@opensuse.org
- Add %%glib2_gsettings_schema_* schema handling in preamble and
  post/postun.
- Don't complicate post/postun with checks for obsoleted openSUSE
  versions.
* Mon Mar 26 2012 zaitor@opensuse.org
- Update to version 0.9.0:
  + Removed ‘definitions’ in favour of hyperlinks.
  + Move to a new XML-based entry serialisation format.
  + Use the new GApplication single instance mechanism.
  + Various fixes to the import system.
  + Search is now asynchronous and case-insensitive.
  + Fixed build with --enable-spell-checking and
  - -disable-encryption.
  + The first phase of a major re-working of the UI to make it more
    GNOME-3-ish.
  + Re-enable spell checking with GTK+3.
  + Automatically save the current entry every 5 minutes.
  + Bugs fixed: bgo#631835, bgo#622193, bgo#647691, bgo#647690,
    bgo#662016, bgo#662014, bgo#667263, bgo#666801, bgo#671801,
    bgo#669927.
  + Updated translations.
- Drop almanah-largefile.patch: fixed upstream.
- Remove gnome-common BuildRequires and call to gnome-autogen.sh:
  they were only needed for above patch.
- Add pkgconfig(gtkspell-3.0) BuildRequires for spell checking
  support.
* Sat Mar  3 2012 dimstar@opensuse.org
- Add X-SuSE-DesktopUtility to the categories of almanah in order
  to fix the build.
* Sat Dec 24 2011 vuntz@opensuse.org
- Add almanah-largefile.patch to fix build, instead of changing
  CFLAGS.
- Cleanup for inclusion in Factory.
* Sat Dec  3 2011 badshah400@gmail.com
- Initial package (version 0.8.0)
